#
# fishing.R, 26 Nov 23
#
# Data from:
# https://arxiv.org/abs/1901.01621

library("colorspace")
library("plyr")


# Plot number of tasks having a given reported actual time
act_counts=function(est_val, low_peak=7)
{
   peak_info=function(some_p)
   {
   num_tasks=sum(act_1hr$freq[peaks][some_p])
   }

sip_1hr=subset(sip_u, HoursEstimate == est_val)

act_1hr=count(round(sip_1hr$HoursActual*4, digits=1)/4) # Pick out 1/4 hour roundings

points(act_1hr, col=pal_col[2])

peaks=which(act_1hr$freq >= low_peak)
text(act_1hr$x[peaks], act_1hr$freq[peaks]*1.1, act_1hr$x[peaks], col=pal_col[1]) 

text(10, 500, paste0("estimate=", trunc(est_val), "-hour"))

# Fraction of tasks in a peak below/at/above estimate
print(c(est_val, nrow(sip_1hr),
			peak_info(which(act_1hr$x[peaks] < est_val))/nrow(sip_1hr),
			peak_info(which(act_1hr$x[peaks] == est_val))/nrow(sip_1hr),
			peak_info(which(act_1hr$x[peaks] > est_val))/nrow(sip_1hr)))
}


hour_frac_count=function(est_val)
{
sip_1hr=subset(sip_u, HoursEstimate == est_val)

sip_1hr$minutes=60*(sip_1hr$HoursActual-trunc(sip_1hr$HoursActual))

# a_less=subset(sip_1hr, HoursActual < HoursEstimate)
# a_more=subset(sip_1hr, HoursActual > HoursEstimate)

# l_count=count(a_less$minutes)
# points(l_count$x, l_count$freq/nrow(sip_1hr), col="green")
# m_count=count(a_more$minutes)
# points(m_count$x, m_count$freq/nrow(sip_1hr), col="blue")

all_cnt=count(sip_1hr$minutes)
points(all_cnt$x, all_cnt$freq/nrow(sip_1hr))

m15=subset(all_cnt, x %in% c(0, 15, 30, 45))

print(c(sum(m15$freq)/sum(all_cnt$freq)))
}


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)

sip=read.csv("Sip-task-info.csv", as.is=TRUE)

# One row from each task
sip_u=subset(sip, !duplicated(TaskNumber))


# Select tasks estimated at 1-hour
plot(0.1, log="xy", type="n",
	xlim=c(0.2, 20), ylim=c(1, 750),
	xlab="Actual (hours)", ylab="Tasks")
# and count the number of them having a given actual.
act_counts(1, low_peak=10)

dev.copy(dev=png, file="est-1hr_actuals.png")
dev.off()

plot(0.1, log="xy", type="n",
	xlim=c(0.2, 20), ylim=c(1, 750),
	xlab="Actual (hours)", ylab="Tasks")
act_counts(7, low_peak=10)

dev.copy(dev=png, file="est-7hr_actuals.png")
dev.off()

# Plot task counts for minute component of actual implementation time
plot(0.0, type="n", log="y",
	xaxs="i", yaxs="i",
	xlim=c(-1.0, 60.0), ylim=c(9e-4, 1),
	xlab="Minute of the hour", ylab="Fraction of Tasks")

hour_frac_count(1)
hour_frac_count(2)
hour_frac_count(3)
hour_frac_count(5)
hour_frac_count(7)
hour_frac_count(14)

dev.copy(dev=png, file="est_act_minute.png")
dev.off()

